# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from herdsdk.api_client import ApiClient


class NamespaceApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def namespace_create_namespace(self, namespace_create_request, **kwargs):  # noqa: E501
        """createNamespace  # noqa: E501

        Creates a new namespace.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.namespace_create_namespace(namespace_create_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param NamespaceCreateRequest namespace_create_request: the information needed to create the namespace (required)
        :return: Namespace
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.namespace_create_namespace_with_http_info(namespace_create_request, **kwargs)  # noqa: E501
        else:
            (data) = self.namespace_create_namespace_with_http_info(namespace_create_request, **kwargs)  # noqa: E501
            return data

    def namespace_create_namespace_with_http_info(self, namespace_create_request, **kwargs):  # noqa: E501
        """createNamespace  # noqa: E501

        Creates a new namespace.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.namespace_create_namespace_with_http_info(namespace_create_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param NamespaceCreateRequest namespace_create_request: the information needed to create the namespace (required)
        :return: Namespace
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['namespace_create_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method namespace_create_namespace" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'namespace_create_request' is set
        if ('namespace_create_request' not in local_var_params or
                local_var_params['namespace_create_request'] is None):
            raise ValueError("Missing the required parameter `namespace_create_request` when calling `namespace_create_namespace`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'namespace_create_request' in local_var_params:
            body_params = local_var_params['namespace_create_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/namespaces', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Namespace',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def namespace_delete_namespace(self, namespace_code, **kwargs):  # noqa: E501
        """deleteNamespace  # noqa: E501

        Deletes an existing namespace by namespace code.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.namespace_delete_namespace(namespace_code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str namespace_code: the namespace code (required)
        :return: Namespace
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.namespace_delete_namespace_with_http_info(namespace_code, **kwargs)  # noqa: E501
        else:
            (data) = self.namespace_delete_namespace_with_http_info(namespace_code, **kwargs)  # noqa: E501
            return data

    def namespace_delete_namespace_with_http_info(self, namespace_code, **kwargs):  # noqa: E501
        """deleteNamespace  # noqa: E501

        Deletes an existing namespace by namespace code.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.namespace_delete_namespace_with_http_info(namespace_code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str namespace_code: the namespace code (required)
        :return: Namespace
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['namespace_code']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method namespace_delete_namespace" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'namespace_code' is set
        if ('namespace_code' not in local_var_params or
                local_var_params['namespace_code'] is None):
            raise ValueError("Missing the required parameter `namespace_code` when calling `namespace_delete_namespace`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'namespace_code' in local_var_params:
            path_params['namespaceCode'] = local_var_params['namespace_code']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/namespaces/{namespaceCode}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Namespace',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def namespace_get_namespace(self, namespace_code, **kwargs):  # noqa: E501
        """getNamespace  # noqa: E501

        Gets an existing namespace by namespace code.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.namespace_get_namespace(namespace_code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str namespace_code: the namespace code (required)
        :return: Namespace
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.namespace_get_namespace_with_http_info(namespace_code, **kwargs)  # noqa: E501
        else:
            (data) = self.namespace_get_namespace_with_http_info(namespace_code, **kwargs)  # noqa: E501
            return data

    def namespace_get_namespace_with_http_info(self, namespace_code, **kwargs):  # noqa: E501
        """getNamespace  # noqa: E501

        Gets an existing namespace by namespace code.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.namespace_get_namespace_with_http_info(namespace_code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str namespace_code: the namespace code (required)
        :return: Namespace
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['namespace_code']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method namespace_get_namespace" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'namespace_code' is set
        if ('namespace_code' not in local_var_params or
                local_var_params['namespace_code'] is None):
            raise ValueError("Missing the required parameter `namespace_code` when calling `namespace_get_namespace`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'namespace_code' in local_var_params:
            path_params['namespaceCode'] = local_var_params['namespace_code']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/namespaces/{namespaceCode}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Namespace',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def namespace_get_namespaces(self, **kwargs):  # noqa: E501
        """getNamespaces  # noqa: E501

        Gets a list of namespace keys for all namespaces defined in the system.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.namespace_get_namespaces(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: NamespaceKeys
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.namespace_get_namespaces_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.namespace_get_namespaces_with_http_info(**kwargs)  # noqa: E501
            return data

    def namespace_get_namespaces_with_http_info(self, **kwargs):  # noqa: E501
        """getNamespaces  # noqa: E501

        Gets a list of namespace keys for all namespaces defined in the system.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.namespace_get_namespaces_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: NamespaceKeys
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method namespace_get_namespaces" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/namespaces', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='NamespaceKeys',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def namespace_search_namespaces(self, namespace_search_request, **kwargs):  # noqa: E501
        """searchNamespaces  # noqa: E501

        Retrieves all namespaces existing in the system per specified search filters and keys.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.namespace_search_namespaces(namespace_search_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param NamespaceSearchRequest namespace_search_request: the namespace search request. The request can only accept a single search filter and a single search key (required)
        :param str fields: the field options for the namespace search response. The valid field options are: chargeCode, s3KeyPrefix
        :return: NamespaceSearchResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.namespace_search_namespaces_with_http_info(namespace_search_request, **kwargs)  # noqa: E501
        else:
            (data) = self.namespace_search_namespaces_with_http_info(namespace_search_request, **kwargs)  # noqa: E501
            return data

    def namespace_search_namespaces_with_http_info(self, namespace_search_request, **kwargs):  # noqa: E501
        """searchNamespaces  # noqa: E501

        Retrieves all namespaces existing in the system per specified search filters and keys.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.namespace_search_namespaces_with_http_info(namespace_search_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param NamespaceSearchRequest namespace_search_request: the namespace search request. The request can only accept a single search filter and a single search key (required)
        :param str fields: the field options for the namespace search response. The valid field options are: chargeCode, s3KeyPrefix
        :return: NamespaceSearchResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['namespace_search_request', 'fields']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method namespace_search_namespaces" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'namespace_search_request' is set
        if ('namespace_search_request' not in local_var_params or
                local_var_params['namespace_search_request'] is None):
            raise ValueError("Missing the required parameter `namespace_search_request` when calling `namespace_search_namespaces`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'fields' in local_var_params:
            query_params.append(('fields', local_var_params['fields']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'namespace_search_request' in local_var_params:
            body_params = local_var_params['namespace_search_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/namespaces/search', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='NamespaceSearchResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def namespace_update_namespaces(self, namespace_code, namespace_update_request, **kwargs):  # noqa: E501
        """updateNamespaces  # noqa: E501

        Updates an existing namespace.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.namespace_update_namespaces(namespace_code, namespace_update_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str namespace_code: (required)
        :param NamespaceUpdateRequest namespace_update_request: (required)
        :return: Namespace
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.namespace_update_namespaces_with_http_info(namespace_code, namespace_update_request, **kwargs)  # noqa: E501
        else:
            (data) = self.namespace_update_namespaces_with_http_info(namespace_code, namespace_update_request, **kwargs)  # noqa: E501
            return data

    def namespace_update_namespaces_with_http_info(self, namespace_code, namespace_update_request, **kwargs):  # noqa: E501
        """updateNamespaces  # noqa: E501

        Updates an existing namespace.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.namespace_update_namespaces_with_http_info(namespace_code, namespace_update_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str namespace_code: (required)
        :param NamespaceUpdateRequest namespace_update_request: (required)
        :return: Namespace
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['namespace_code', 'namespace_update_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method namespace_update_namespaces" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'namespace_code' is set
        if ('namespace_code' not in local_var_params or
                local_var_params['namespace_code'] is None):
            raise ValueError("Missing the required parameter `namespace_code` when calling `namespace_update_namespaces`")  # noqa: E501
        # verify the required parameter 'namespace_update_request' is set
        if ('namespace_update_request' not in local_var_params or
                local_var_params['namespace_update_request'] is None):
            raise ValueError("Missing the required parameter `namespace_update_request` when calling `namespace_update_namespaces`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'namespace_code' in local_var_params:
            path_params['namespaceCode'] = local_var_params['namespace_code']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'namespace_update_request' in local_var_params:
            body_params = local_var_params['namespace_update_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/namespaces/{namespaceCode}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Namespace',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class Parameter(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'value': 'str'
    }

    attribute_map = {
        'name': 'name',
        'value': 'value'
    }

    def __init__(self, name=None, value=None):  # noqa: E501
        """Parameter - a model defined in OpenAPI"""  # noqa: E501

        self._name = None
        self._value = None
        self.discriminator = None

        self.name = name
        if value is not None:
            self.value = value

    @property
    def name(self):
        """Gets the name of this Parameter.  # noqa: E501

        Name of the parameter  # noqa: E501

        :return: The name of this Parameter.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Parameter.

        Name of the parameter  # noqa: E501

        :param name: The name of this Parameter.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def value(self):
        """Gets the value of this Parameter.  # noqa: E501

        Value of the parameter. If the name of the parameter contains the word \"password,\" this value will be masked before being                   logged into the                   application logs                  # noqa: E501

        :return: The value of this Parameter.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this Parameter.

        Value of the parameter. If the name of the parameter contains the word \"password,\" this value will be masked before being                   logged into the                   application logs                  # noqa: E501

        :param value: The value of this Parameter.  # noqa: E501
        :type: str
        """

        self._value = value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Parameter):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import herdsdk
from herdsdk.api.business_object_data_api import BusinessObjectDataApi  # noqa: E501
from herdsdk.rest import ApiException


class TestBusinessObjectDataApi(unittest.TestCase):
    """BusinessObjectDataApi unit test stubs"""

    def setUp(self):
        self.api = herdsdk.api.business_object_data_api.BusinessObjectDataApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_business_object_data_check_business_object_data_availability(self):
        """Test case for business_object_data_check_business_object_data_availability

        checkBusinessObjectDataAvailability  # noqa: E501
        """
        pass

    def test_business_object_data_check_business_object_data_availability_collection(self):
        """Test case for business_object_data_check_business_object_data_availability_collection

        checkBusinessObjectDataAvailabilityCollection  # noqa: E501
        """
        pass

    def test_business_object_data_create_business_object_data(self):
        """Test case for business_object_data_create_business_object_data

        createBusinessObjectData  # noqa: E501
        """
        pass

    def test_business_object_data_delete_business_object_data(self):
        """Test case for business_object_data_delete_business_object_data

        deleteBusinessObjectData  # noqa: E501
        """
        pass

    def test_business_object_data_delete_business_object_data1(self):
        """Test case for business_object_data_delete_business_object_data1

        deleteBusinessObjectData  # noqa: E501
        """
        pass

    def test_business_object_data_delete_business_object_data2(self):
        """Test case for business_object_data_delete_business_object_data2

        deleteBusinessObjectData  # noqa: E501
        """
        pass

    def test_business_object_data_delete_business_object_data3(self):
        """Test case for business_object_data_delete_business_object_data3

        deleteBusinessObjectData  # noqa: E501
        """
        pass

    def test_business_object_data_delete_business_object_data4(self):
        """Test case for business_object_data_delete_business_object_data4

        deleteBusinessObjectData  # noqa: E501
        """
        pass

    def test_business_object_data_destroy_business_object_data(self):
        """Test case for business_object_data_destroy_business_object_data

        destroyBusinessObjectData  # noqa: E501
        """
        pass

    def test_business_object_data_generate_business_object_data_ddl(self):
        """Test case for business_object_data_generate_business_object_data_ddl

        generateBusinessObjectDataDdl  # noqa: E501
        """
        pass

    def test_business_object_data_generate_business_object_data_ddl_collection(self):
        """Test case for business_object_data_generate_business_object_data_ddl_collection

        generateBusinessObjectDataDdlCollection  # noqa: E501
        """
        pass

    def test_business_object_data_generate_business_object_data_partitions(self):
        """Test case for business_object_data_generate_business_object_data_partitions

        generateBusinessObjectDataPartitions  # noqa: E501
        """
        pass

    def test_business_object_data_get_all_business_object_data_by_business_object_definition(self):
        """Test case for business_object_data_get_all_business_object_data_by_business_object_definition

        getAllBusinessObjectDataByBusinessObjectDefinition  # noqa: E501
        """
        pass

    def test_business_object_data_get_all_business_object_data_by_business_object_format(self):
        """Test case for business_object_data_get_all_business_object_data_by_business_object_format

        getAllBusinessObjectDataByBusinessObjectFormat  # noqa: E501
        """
        pass

    def test_business_object_data_get_business_object_data(self):
        """Test case for business_object_data_get_business_object_data

        getBusinessObjectData  # noqa: E501
        """
        pass

    def test_business_object_data_get_business_object_data_versions(self):
        """Test case for business_object_data_get_business_object_data_versions

        getBusinessObjectDataVersions  # noqa: E501
        """
        pass

    def test_business_object_data_get_s3_key_prefix(self):
        """Test case for business_object_data_get_s3_key_prefix

        Gets the S3 key prefix information for a specified namespace  # noqa: E501
        """
        pass

    def test_business_object_data_invalidate_unregistered_business_object_data(self):
        """Test case for business_object_data_invalidate_unregistered_business_object_data

        invalidateUnregisteredBusinessObjectData  # noqa: E501
        """
        pass

    def test_business_object_data_restore_business_object_data(self):
        """Test case for business_object_data_restore_business_object_data

        restoreBusinessObjectData  # noqa: E501
        """
        pass

    def test_business_object_data_retry_storage_policy_transition(self):
        """Test case for business_object_data_retry_storage_policy_transition

        retryStoragePolicyTransition  # noqa: E501
        """
        pass

    def test_business_object_data_search_business_object_data(self):
        """Test case for business_object_data_search_business_object_data

        searchBusinessObjectData  # noqa: E501
        """
        pass

    def test_business_object_data_update_business_object_data_attributes(self):
        """Test case for business_object_data_update_business_object_data_attributes

        updateBusinessObjectDataAttributes  # noqa: E501
        """
        pass

    def test_business_object_data_update_business_object_data_attributes1(self):
        """Test case for business_object_data_update_business_object_data_attributes1

        updateBusinessObjectDataAttributes  # noqa: E501
        """
        pass

    def test_business_object_data_update_business_object_data_attributes2(self):
        """Test case for business_object_data_update_business_object_data_attributes2

        updateBusinessObjectDataAttributes  # noqa: E501
        """
        pass

    def test_business_object_data_update_business_object_data_attributes3(self):
        """Test case for business_object_data_update_business_object_data_attributes3

        updateBusinessObjectDataAttributes  # noqa: E501
        """
        pass

    def test_business_object_data_update_business_object_data_attributes4(self):
        """Test case for business_object_data_update_business_object_data_attributes4

        updateBusinessObjectDataAttributes  # noqa: E501
        """
        pass

    def test_business_object_data_update_business_object_data_legal_hold(self):
        """Test case for business_object_data_update_business_object_data_legal_hold

        updateBusinessObjectDataLegalHold  # noqa: E501
        """
        pass

    def test_business_object_data_update_business_object_data_parents(self):
        """Test case for business_object_data_update_business_object_data_parents

        updateBusinessObjectDataParents  # noqa: E501
        """
        pass

    def test_business_object_data_update_business_object_data_retention_information(self):
        """Test case for business_object_data_update_business_object_data_retention_information

        updateBusinessObjectDataRetentionInformation  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BusinessObjectDefinitionChangeEvent(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'display_name': 'str',
        'description': 'str',
        'descriptive_business_object_format': 'DescriptiveBusinessObjectFormatUpdateRequest',
        'event_time': 'datetime',
        'user_id': 'str'
    }

    attribute_map = {
        'display_name': 'displayName',
        'description': 'description',
        'descriptive_business_object_format': 'descriptiveBusinessObjectFormat',
        'event_time': 'eventTime',
        'user_id': 'userId'
    }

    def __init__(self, display_name=None, description=None, descriptive_business_object_format=None, event_time=None, user_id=None):  # noqa: E501
        """BusinessObjectDefinitionChangeEvent - a model defined in OpenAPI"""  # noqa: E501

        self._display_name = None
        self._description = None
        self._descriptive_business_object_format = None
        self._event_time = None
        self._user_id = None
        self.discriminator = None

        if display_name is not None:
            self.display_name = display_name
        if description is not None:
            self.description = description
        if descriptive_business_object_format is not None:
            self.descriptive_business_object_format = descriptive_business_object_format
        self.event_time = event_time
        self.user_id = user_id

    @property
    def display_name(self):
        """Gets the display_name of this BusinessObjectDefinitionChangeEvent.  # noqa: E501

        Business friendly name  # noqa: E501

        :return: The display_name of this BusinessObjectDefinitionChangeEvent.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this BusinessObjectDefinitionChangeEvent.

        Business friendly name  # noqa: E501

        :param display_name: The display_name of this BusinessObjectDefinitionChangeEvent.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def description(self):
        """Gets the description of this BusinessObjectDefinitionChangeEvent.  # noqa: E501

        Description of the Business Object Definition  # noqa: E501

        :return: The description of this BusinessObjectDefinitionChangeEvent.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this BusinessObjectDefinitionChangeEvent.

        Description of the Business Object Definition  # noqa: E501

        :param description: The description of this BusinessObjectDefinitionChangeEvent.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def descriptive_business_object_format(self):
        """Gets the descriptive_business_object_format of this BusinessObjectDefinitionChangeEvent.  # noqa: E501


        :return: The descriptive_business_object_format of this BusinessObjectDefinitionChangeEvent.  # noqa: E501
        :rtype: DescriptiveBusinessObjectFormatUpdateRequest
        """
        return self._descriptive_business_object_format

    @descriptive_business_object_format.setter
    def descriptive_business_object_format(self, descriptive_business_object_format):
        """Sets the descriptive_business_object_format of this BusinessObjectDefinitionChangeEvent.


        :param descriptive_business_object_format: The descriptive_business_object_format of this BusinessObjectDefinitionChangeEvent.  # noqa: E501
        :type: DescriptiveBusinessObjectFormatUpdateRequest
        """

        self._descriptive_business_object_format = descriptive_business_object_format

    @property
    def event_time(self):
        """Gets the event_time of this BusinessObjectDefinitionChangeEvent.  # noqa: E501

        The timestamp of when the business object definition update occured  # noqa: E501

        :return: The event_time of this BusinessObjectDefinitionChangeEvent.  # noqa: E501
        :rtype: datetime
        """
        return self._event_time

    @event_time.setter
    def event_time(self, event_time):
        """Sets the event_time of this BusinessObjectDefinitionChangeEvent.

        The timestamp of when the business object definition update occured  # noqa: E501

        :param event_time: The event_time of this BusinessObjectDefinitionChangeEvent.  # noqa: E501
        :type: datetime
        """
        if event_time is None:
            raise ValueError("Invalid value for `event_time`, must not be `None`")  # noqa: E501

        self._event_time = event_time

    @property
    def user_id(self):
        """Gets the user_id of this BusinessObjectDefinitionChangeEvent.  # noqa: E501

        The User ID of the user who performed business object definition update  # noqa: E501

        :return: The user_id of this BusinessObjectDefinitionChangeEvent.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this BusinessObjectDefinitionChangeEvent.

        The User ID of the user who performed business object definition update  # noqa: E501

        :param user_id: The user_id of this BusinessObjectDefinitionChangeEvent.  # noqa: E501
        :type: str
        """
        if user_id is None:
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BusinessObjectDefinitionChangeEvent):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class Tag(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'tag_key': 'TagKey',
        'display_name': 'str',
        'search_score_multiplier': 'float',
        'description': 'str',
        'user_id': 'str',
        'last_updated_by_user_id': 'str',
        'updated_time': 'datetime',
        'parent_tag_key': 'TagKey',
        'has_children': 'bool'
    }

    attribute_map = {
        'id': 'id',
        'tag_key': 'tagKey',
        'display_name': 'displayName',
        'search_score_multiplier': 'searchScoreMultiplier',
        'description': 'description',
        'user_id': 'userId',
        'last_updated_by_user_id': 'lastUpdatedByUserId',
        'updated_time': 'updatedTime',
        'parent_tag_key': 'parentTagKey',
        'has_children': 'hasChildren'
    }

    def __init__(self, id=None, tag_key=None, display_name=None, search_score_multiplier=None, description=None, user_id=None, last_updated_by_user_id=None, updated_time=None, parent_tag_key=None, has_children=None):  # noqa: E501
        """Tag - a model defined in OpenAPI"""  # noqa: E501

        self._id = None
        self._tag_key = None
        self._display_name = None
        self._search_score_multiplier = None
        self._description = None
        self._user_id = None
        self._last_updated_by_user_id = None
        self._updated_time = None
        self._parent_tag_key = None
        self._has_children = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.tag_key = tag_key
        if display_name is not None:
            self.display_name = display_name
        if search_score_multiplier is not None:
            self.search_score_multiplier = search_score_multiplier
        if description is not None:
            self.description = description
        if user_id is not None:
            self.user_id = user_id
        if last_updated_by_user_id is not None:
            self.last_updated_by_user_id = last_updated_by_user_id
        if updated_time is not None:
            self.updated_time = updated_time
        if parent_tag_key is not None:
            self.parent_tag_key = parent_tag_key
        if has_children is not None:
            self.has_children = has_children

    @property
    def id(self):
        """Gets the id of this Tag.  # noqa: E501

        The internal identifier that uniquely references a Tag  # noqa: E501

        :return: The id of this Tag.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Tag.

        The internal identifier that uniquely references a Tag  # noqa: E501

        :param id: The id of this Tag.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def tag_key(self):
        """Gets the tag_key of this Tag.  # noqa: E501


        :return: The tag_key of this Tag.  # noqa: E501
        :rtype: TagKey
        """
        return self._tag_key

    @tag_key.setter
    def tag_key(self, tag_key):
        """Sets the tag_key of this Tag.


        :param tag_key: The tag_key of this Tag.  # noqa: E501
        :type: TagKey
        """
        if tag_key is None:
            raise ValueError("Invalid value for `tag_key`, must not be `None`")  # noqa: E501

        self._tag_key = tag_key

    @property
    def display_name(self):
        """Gets the display_name of this Tag.  # noqa: E501

        The tag's name in plain text for human readability  # noqa: E501

        :return: The display_name of this Tag.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this Tag.

        The tag's name in plain text for human readability  # noqa: E501

        :param display_name: The display_name of this Tag.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def search_score_multiplier(self):
        """Gets the search_score_multiplier of this Tag.  # noqa: E501

        An optional tag's search score multiplier. Search score multiplier is numeric and can be a decimal  # noqa: E501

        :return: The search_score_multiplier of this Tag.  # noqa: E501
        :rtype: float
        """
        return self._search_score_multiplier

    @search_score_multiplier.setter
    def search_score_multiplier(self, search_score_multiplier):
        """Sets the search_score_multiplier of this Tag.

        An optional tag's search score multiplier. Search score multiplier is numeric and can be a decimal  # noqa: E501

        :param search_score_multiplier: The search_score_multiplier of this Tag.  # noqa: E501
        :type: float
        """

        self._search_score_multiplier = search_score_multiplier

    @property
    def description(self):
        """Gets the description of this Tag.  # noqa: E501

        The tag's description  # noqa: E501

        :return: The description of this Tag.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Tag.

        The tag's description  # noqa: E501

        :param description: The description of this Tag.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def user_id(self):
        """Gets the user_id of this Tag.  # noqa: E501

        The User ID of the user who created this tag  # noqa: E501

        :return: The user_id of this Tag.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this Tag.

        The User ID of the user who created this tag  # noqa: E501

        :param user_id: The user_id of this Tag.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def last_updated_by_user_id(self):
        """Gets the last_updated_by_user_id of this Tag.  # noqa: E501

        The User ID of the user who last updated this tag  # noqa: E501

        :return: The last_updated_by_user_id of this Tag.  # noqa: E501
        :rtype: str
        """
        return self._last_updated_by_user_id

    @last_updated_by_user_id.setter
    def last_updated_by_user_id(self, last_updated_by_user_id):
        """Sets the last_updated_by_user_id of this Tag.

        The User ID of the user who last updated this tag  # noqa: E501

        :param last_updated_by_user_id: The last_updated_by_user_id of this Tag.  # noqa: E501
        :type: str
        """

        self._last_updated_by_user_id = last_updated_by_user_id

    @property
    def updated_time(self):
        """Gets the updated_time of this Tag.  # noqa: E501

        The timestamp of when it is last updated  # noqa: E501

        :return: The updated_time of this Tag.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_time

    @updated_time.setter
    def updated_time(self, updated_time):
        """Sets the updated_time of this Tag.

        The timestamp of when it is last updated  # noqa: E501

        :param updated_time: The updated_time of this Tag.  # noqa: E501
        :type: datetime
        """

        self._updated_time = updated_time

    @property
    def parent_tag_key(self):
        """Gets the parent_tag_key of this Tag.  # noqa: E501


        :return: The parent_tag_key of this Tag.  # noqa: E501
        :rtype: TagKey
        """
        return self._parent_tag_key

    @parent_tag_key.setter
    def parent_tag_key(self, parent_tag_key):
        """Sets the parent_tag_key of this Tag.


        :param parent_tag_key: The parent_tag_key of this Tag.  # noqa: E501
        :type: TagKey
        """

        self._parent_tag_key = parent_tag_key

    @property
    def has_children(self):
        """Gets the has_children of this Tag.  # noqa: E501

        A boolean flag that shows whether this tag has further children  # noqa: E501

        :return: The has_children of this Tag.  # noqa: E501
        :rtype: bool
        """
        return self._has_children

    @has_children.setter
    def has_children(self, has_children):
        """Sets the has_children of this Tag.

        A boolean flag that shows whether this tag has further children  # noqa: E501

        :param has_children: The has_children of this Tag.  # noqa: E501
        :type: bool
        """

        self._has_children = has_children

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Tag):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class JdbcStatement(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'type': 'str',
        'sql': 'str',
        'continue_on_error': 'bool',
        'status': 'str',
        'result': 'str',
        'result_set': 'JdbcStatementResultSet',
        'error_message': 'str'
    }

    attribute_map = {
        'type': 'type',
        'sql': 'sql',
        'continue_on_error': 'continueOnError',
        'status': 'status',
        'result': 'result',
        'result_set': 'resultSet',
        'error_message': 'errorMessage'
    }

    def __init__(self, type=None, sql=None, continue_on_error=None, status=None, result=None, result_set=None, error_message=None):  # noqa: E501
        """JdbcStatement - a model defined in OpenAPI"""  # noqa: E501

        self._type = None
        self._sql = None
        self._continue_on_error = None
        self._status = None
        self._result = None
        self._result_set = None
        self._error_message = None
        self.discriminator = None

        self.type = type
        self.sql = sql
        if continue_on_error is not None:
            self.continue_on_error = continue_on_error
        if status is not None:
            self.status = status
        if result is not None:
            self.result = result
        if result_set is not None:
            self.result_set = result_set
        if error_message is not None:
            self.error_message = error_message

    @property
    def type(self):
        """Gets the type of this JdbcStatement.  # noqa: E501


        :return: The type of this JdbcStatement.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this JdbcStatement.


        :param type: The type of this JdbcStatement.  # noqa: E501
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["UPDATE", "QUERY"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def sql(self):
        """Gets the sql of this JdbcStatement.  # noqa: E501


        :return: The sql of this JdbcStatement.  # noqa: E501
        :rtype: str
        """
        return self._sql

    @sql.setter
    def sql(self, sql):
        """Sets the sql of this JdbcStatement.


        :param sql: The sql of this JdbcStatement.  # noqa: E501
        :type: str
        """
        if sql is None:
            raise ValueError("Invalid value for `sql`, must not be `None`")  # noqa: E501

        self._sql = sql

    @property
    def continue_on_error(self):
        """Gets the continue_on_error of this JdbcStatement.  # noqa: E501


        :return: The continue_on_error of this JdbcStatement.  # noqa: E501
        :rtype: bool
        """
        return self._continue_on_error

    @continue_on_error.setter
    def continue_on_error(self, continue_on_error):
        """Sets the continue_on_error of this JdbcStatement.


        :param continue_on_error: The continue_on_error of this JdbcStatement.  # noqa: E501
        :type: bool
        """

        self._continue_on_error = continue_on_error

    @property
    def status(self):
        """Gets the status of this JdbcStatement.  # noqa: E501


        :return: The status of this JdbcStatement.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this JdbcStatement.


        :param status: The status of this JdbcStatement.  # noqa: E501
        :type: str
        """
        allowed_values = ["SUCCESS", "ERROR", "SKIPPED"]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def result(self):
        """Gets the result of this JdbcStatement.  # noqa: E501


        :return: The result of this JdbcStatement.  # noqa: E501
        :rtype: str
        """
        return self._result

    @result.setter
    def result(self, result):
        """Sets the result of this JdbcStatement.


        :param result: The result of this JdbcStatement.  # noqa: E501
        :type: str
        """

        self._result = result

    @property
    def result_set(self):
        """Gets the result_set of this JdbcStatement.  # noqa: E501


        :return: The result_set of this JdbcStatement.  # noqa: E501
        :rtype: JdbcStatementResultSet
        """
        return self._result_set

    @result_set.setter
    def result_set(self, result_set):
        """Sets the result_set of this JdbcStatement.


        :param result_set: The result_set of this JdbcStatement.  # noqa: E501
        :type: JdbcStatementResultSet
        """

        self._result_set = result_set

    @property
    def error_message(self):
        """Gets the error_message of this JdbcStatement.  # noqa: E501


        :return: The error_message of this JdbcStatement.  # noqa: E501
        :rtype: str
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        """Sets the error_message of this JdbcStatement.


        :param error_message: The error_message of this JdbcStatement.  # noqa: E501
        :type: str
        """

        self._error_message = error_message

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JdbcStatement):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class NotificationMessageDefinition(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'message_type': 'str',
        'message_destination': 'str',
        'message_velocity_template': 'str',
        'message_header_definitions': 'list[MessageHeaderDefinition]'
    }

    attribute_map = {
        'message_type': 'messageType',
        'message_destination': 'messageDestination',
        'message_velocity_template': 'messageVelocityTemplate',
        'message_header_definitions': 'messageHeaderDefinitions'
    }

    def __init__(self, message_type=None, message_destination=None, message_velocity_template=None, message_header_definitions=None):  # noqa: E501
        """NotificationMessageDefinition - a model defined in OpenAPI"""  # noqa: E501

        self._message_type = None
        self._message_destination = None
        self._message_velocity_template = None
        self._message_header_definitions = None
        self.discriminator = None

        if message_type is not None:
            self.message_type = message_type
        if message_destination is not None:
            self.message_destination = message_destination
        if message_velocity_template is not None:
            self.message_velocity_template = message_velocity_template
        if message_header_definitions is not None:
            self.message_header_definitions = message_header_definitions

    @property
    def message_type(self):
        """Gets the message_type of this NotificationMessageDefinition.  # noqa: E501


        :return: The message_type of this NotificationMessageDefinition.  # noqa: E501
        :rtype: str
        """
        return self._message_type

    @message_type.setter
    def message_type(self, message_type):
        """Sets the message_type of this NotificationMessageDefinition.


        :param message_type: The message_type of this NotificationMessageDefinition.  # noqa: E501
        :type: str
        """

        self._message_type = message_type

    @property
    def message_destination(self):
        """Gets the message_destination of this NotificationMessageDefinition.  # noqa: E501


        :return: The message_destination of this NotificationMessageDefinition.  # noqa: E501
        :rtype: str
        """
        return self._message_destination

    @message_destination.setter
    def message_destination(self, message_destination):
        """Sets the message_destination of this NotificationMessageDefinition.


        :param message_destination: The message_destination of this NotificationMessageDefinition.  # noqa: E501
        :type: str
        """

        self._message_destination = message_destination

    @property
    def message_velocity_template(self):
        """Gets the message_velocity_template of this NotificationMessageDefinition.  # noqa: E501


        :return: The message_velocity_template of this NotificationMessageDefinition.  # noqa: E501
        :rtype: str
        """
        return self._message_velocity_template

    @message_velocity_template.setter
    def message_velocity_template(self, message_velocity_template):
        """Sets the message_velocity_template of this NotificationMessageDefinition.


        :param message_velocity_template: The message_velocity_template of this NotificationMessageDefinition.  # noqa: E501
        :type: str
        """

        self._message_velocity_template = message_velocity_template

    @property
    def message_header_definitions(self):
        """Gets the message_header_definitions of this NotificationMessageDefinition.  # noqa: E501


        :return: The message_header_definitions of this NotificationMessageDefinition.  # noqa: E501
        :rtype: list[MessageHeaderDefinition]
        """
        return self._message_header_definitions

    @message_header_definitions.setter
    def message_header_definitions(self, message_header_definitions):
        """Sets the message_header_definitions of this NotificationMessageDefinition.


        :param message_header_definitions: The message_header_definitions of this NotificationMessageDefinition.  # noqa: E501
        :type: list[MessageHeaderDefinition]
        """

        self._message_header_definitions = message_header_definitions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NotificationMessageDefinition):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from herdsdk.api_client import ApiClient


class BusinessObjectDefinitionDescriptionSuggestionApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def business_object_definition_description_suggestion_accept_business_object_definition_description_suggestion(self, business_object_definition_description_suggestion_acceptance_request, **kwargs):  # noqa: E501
        """acceptBusinessObjectDefinitionDescriptionSuggestion  # noqa: E501

        Accepts suggested business object definition description suggestion by key and updates the corresponding business object definition description.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_definition_description_suggestion_accept_business_object_definition_description_suggestion(business_object_definition_description_suggestion_acceptance_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param BusinessObjectDefinitionDescriptionSuggestionAcceptanceRequest business_object_definition_description_suggestion_acceptance_request: the information needed to accept the business object definition description suggestion. (required)
        :return: BusinessObjectDefinitionDescriptionSuggestion
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.business_object_definition_description_suggestion_accept_business_object_definition_description_suggestion_with_http_info(business_object_definition_description_suggestion_acceptance_request, **kwargs)  # noqa: E501
        else:
            (data) = self.business_object_definition_description_suggestion_accept_business_object_definition_description_suggestion_with_http_info(business_object_definition_description_suggestion_acceptance_request, **kwargs)  # noqa: E501
            return data

    def business_object_definition_description_suggestion_accept_business_object_definition_description_suggestion_with_http_info(self, business_object_definition_description_suggestion_acceptance_request, **kwargs):  # noqa: E501
        """acceptBusinessObjectDefinitionDescriptionSuggestion  # noqa: E501

        Accepts suggested business object definition description suggestion by key and updates the corresponding business object definition description.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_definition_description_suggestion_accept_business_object_definition_description_suggestion_with_http_info(business_object_definition_description_suggestion_acceptance_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param BusinessObjectDefinitionDescriptionSuggestionAcceptanceRequest business_object_definition_description_suggestion_acceptance_request: the information needed to accept the business object definition description suggestion. (required)
        :return: BusinessObjectDefinitionDescriptionSuggestion
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['business_object_definition_description_suggestion_acceptance_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method business_object_definition_description_suggestion_accept_business_object_definition_description_suggestion" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'business_object_definition_description_suggestion_acceptance_request' is set
        if ('business_object_definition_description_suggestion_acceptance_request' not in local_var_params or
                local_var_params['business_object_definition_description_suggestion_acceptance_request'] is None):
            raise ValueError("Missing the required parameter `business_object_definition_description_suggestion_acceptance_request` when calling `business_object_definition_description_suggestion_accept_business_object_definition_description_suggestion`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'business_object_definition_description_suggestion_acceptance_request' in local_var_params:
            body_params = local_var_params['business_object_definition_description_suggestion_acceptance_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/businessObjectDefinitionDescriptionSuggestions/acceptance', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BusinessObjectDefinitionDescriptionSuggestion',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def business_object_definition_description_suggestion_create_business_object_definition_description_suggestion(self, business_object_definition_description_suggestion_create_request, **kwargs):  # noqa: E501
        """createBusinessObjectDefinitionDescriptionSuggestion  # noqa: E501

        Creates a new business object definition description suggestion.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_definition_description_suggestion_create_business_object_definition_description_suggestion(business_object_definition_description_suggestion_create_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param BusinessObjectDefinitionDescriptionSuggestionCreateRequest business_object_definition_description_suggestion_create_request: the information needed to create the business object definition description suggestion (required)
        :return: BusinessObjectDefinitionDescriptionSuggestion
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.business_object_definition_description_suggestion_create_business_object_definition_description_suggestion_with_http_info(business_object_definition_description_suggestion_create_request, **kwargs)  # noqa: E501
        else:
            (data) = self.business_object_definition_description_suggestion_create_business_object_definition_description_suggestion_with_http_info(business_object_definition_description_suggestion_create_request, **kwargs)  # noqa: E501
            return data

    def business_object_definition_description_suggestion_create_business_object_definition_description_suggestion_with_http_info(self, business_object_definition_description_suggestion_create_request, **kwargs):  # noqa: E501
        """createBusinessObjectDefinitionDescriptionSuggestion  # noqa: E501

        Creates a new business object definition description suggestion.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_definition_description_suggestion_create_business_object_definition_description_suggestion_with_http_info(business_object_definition_description_suggestion_create_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param BusinessObjectDefinitionDescriptionSuggestionCreateRequest business_object_definition_description_suggestion_create_request: the information needed to create the business object definition description suggestion (required)
        :return: BusinessObjectDefinitionDescriptionSuggestion
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['business_object_definition_description_suggestion_create_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method business_object_definition_description_suggestion_create_business_object_definition_description_suggestion" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'business_object_definition_description_suggestion_create_request' is set
        if ('business_object_definition_description_suggestion_create_request' not in local_var_params or
                local_var_params['business_object_definition_description_suggestion_create_request'] is None):
            raise ValueError("Missing the required parameter `business_object_definition_description_suggestion_create_request` when calling `business_object_definition_description_suggestion_create_business_object_definition_description_suggestion`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'business_object_definition_description_suggestion_create_request' in local_var_params:
            body_params = local_var_params['business_object_definition_description_suggestion_create_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/businessObjectDefinitionDescriptionSuggestions', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BusinessObjectDefinitionDescriptionSuggestion',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def business_object_definition_description_suggestion_delete_business_object_definition_description_suggestion(self, namespace, business_object_definition_name, user_id, **kwargs):  # noqa: E501
        """deleteBusinessObjectDefinitionDescriptionSuggestion  # noqa: E501

        Deletes an existing business object definition description suggestion by key.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_definition_description_suggestion_delete_business_object_definition_description_suggestion(namespace, business_object_definition_name, user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str namespace: the namespace (required)
        :param str business_object_definition_name: the business object definition name (required)
        :param str user_id: the user id (required)
        :return: BusinessObjectDefinitionDescriptionSuggestion
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.business_object_definition_description_suggestion_delete_business_object_definition_description_suggestion_with_http_info(namespace, business_object_definition_name, user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.business_object_definition_description_suggestion_delete_business_object_definition_description_suggestion_with_http_info(namespace, business_object_definition_name, user_id, **kwargs)  # noqa: E501
            return data

    def business_object_definition_description_suggestion_delete_business_object_definition_description_suggestion_with_http_info(self, namespace, business_object_definition_name, user_id, **kwargs):  # noqa: E501
        """deleteBusinessObjectDefinitionDescriptionSuggestion  # noqa: E501

        Deletes an existing business object definition description suggestion by key.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_definition_description_suggestion_delete_business_object_definition_description_suggestion_with_http_info(namespace, business_object_definition_name, user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str namespace: the namespace (required)
        :param str business_object_definition_name: the business object definition name (required)
        :param str user_id: the user id (required)
        :return: BusinessObjectDefinitionDescriptionSuggestion
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['namespace', 'business_object_definition_name', 'user_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method business_object_definition_description_suggestion_delete_business_object_definition_description_suggestion" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'namespace' is set
        if ('namespace' not in local_var_params or
                local_var_params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `business_object_definition_description_suggestion_delete_business_object_definition_description_suggestion`")  # noqa: E501
        # verify the required parameter 'business_object_definition_name' is set
        if ('business_object_definition_name' not in local_var_params or
                local_var_params['business_object_definition_name'] is None):
            raise ValueError("Missing the required parameter `business_object_definition_name` when calling `business_object_definition_description_suggestion_delete_business_object_definition_description_suggestion`")  # noqa: E501
        # verify the required parameter 'user_id' is set
        if ('user_id' not in local_var_params or
                local_var_params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `business_object_definition_description_suggestion_delete_business_object_definition_description_suggestion`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'namespace' in local_var_params:
            path_params['namespace'] = local_var_params['namespace']  # noqa: E501
        if 'business_object_definition_name' in local_var_params:
            path_params['businessObjectDefinitionName'] = local_var_params['business_object_definition_name']  # noqa: E501
        if 'user_id' in local_var_params:
            path_params['userId'] = local_var_params['user_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/businessObjectDefinitionDescriptionSuggestions/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/userIds/{userId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BusinessObjectDefinitionDescriptionSuggestion',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def business_object_definition_description_suggestion_get_business_object_definition_description_suggestion_by_key(self, namespace, business_object_definition_name, user_id, **kwargs):  # noqa: E501
        """getBusinessObjectDefinitionDescriptionSuggestionByKey  # noqa: E501

        Retrieves an existing business object definition description suggestion by key.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_definition_description_suggestion_get_business_object_definition_description_suggestion_by_key(namespace, business_object_definition_name, user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str namespace: the namespace (required)
        :param str business_object_definition_name: the business object definition name (required)
        :param str user_id: the user id (required)
        :return: BusinessObjectDefinitionDescriptionSuggestion
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.business_object_definition_description_suggestion_get_business_object_definition_description_suggestion_by_key_with_http_info(namespace, business_object_definition_name, user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.business_object_definition_description_suggestion_get_business_object_definition_description_suggestion_by_key_with_http_info(namespace, business_object_definition_name, user_id, **kwargs)  # noqa: E501
            return data

    def business_object_definition_description_suggestion_get_business_object_definition_description_suggestion_by_key_with_http_info(self, namespace, business_object_definition_name, user_id, **kwargs):  # noqa: E501
        """getBusinessObjectDefinitionDescriptionSuggestionByKey  # noqa: E501

        Retrieves an existing business object definition description suggestion by key.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_definition_description_suggestion_get_business_object_definition_description_suggestion_by_key_with_http_info(namespace, business_object_definition_name, user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str namespace: the namespace (required)
        :param str business_object_definition_name: the business object definition name (required)
        :param str user_id: the user id (required)
        :return: BusinessObjectDefinitionDescriptionSuggestion
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['namespace', 'business_object_definition_name', 'user_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method business_object_definition_description_suggestion_get_business_object_definition_description_suggestion_by_key" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'namespace' is set
        if ('namespace' not in local_var_params or
                local_var_params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `business_object_definition_description_suggestion_get_business_object_definition_description_suggestion_by_key`")  # noqa: E501
        # verify the required parameter 'business_object_definition_name' is set
        if ('business_object_definition_name' not in local_var_params or
                local_var_params['business_object_definition_name'] is None):
            raise ValueError("Missing the required parameter `business_object_definition_name` when calling `business_object_definition_description_suggestion_get_business_object_definition_description_suggestion_by_key`")  # noqa: E501
        # verify the required parameter 'user_id' is set
        if ('user_id' not in local_var_params or
                local_var_params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `business_object_definition_description_suggestion_get_business_object_definition_description_suggestion_by_key`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'namespace' in local_var_params:
            path_params['namespace'] = local_var_params['namespace']  # noqa: E501
        if 'business_object_definition_name' in local_var_params:
            path_params['businessObjectDefinitionName'] = local_var_params['business_object_definition_name']  # noqa: E501
        if 'user_id' in local_var_params:
            path_params['userId'] = local_var_params['user_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/businessObjectDefinitionDescriptionSuggestions/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/userIds/{userId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BusinessObjectDefinitionDescriptionSuggestion',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def business_object_definition_description_suggestion_get_business_object_definition_description_suggestions(self, namespace, business_object_definition_name, **kwargs):  # noqa: E501
        """getBusinessObjectDefinitionDescriptionSuggestions  # noqa: E501

        Retrieves a list of business object definition description suggestion keys for all suggestions registered for a specific business object definition. The result list is sorted by userId in ascending order.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_definition_description_suggestion_get_business_object_definition_description_suggestions(namespace, business_object_definition_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str namespace: the namespace (required)
        :param str business_object_definition_name: the business object definition name (required)
        :return: BusinessObjectDefinitionDescriptionSuggestionKeys
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.business_object_definition_description_suggestion_get_business_object_definition_description_suggestions_with_http_info(namespace, business_object_definition_name, **kwargs)  # noqa: E501
        else:
            (data) = self.business_object_definition_description_suggestion_get_business_object_definition_description_suggestions_with_http_info(namespace, business_object_definition_name, **kwargs)  # noqa: E501
            return data

    def business_object_definition_description_suggestion_get_business_object_definition_description_suggestions_with_http_info(self, namespace, business_object_definition_name, **kwargs):  # noqa: E501
        """getBusinessObjectDefinitionDescriptionSuggestions  # noqa: E501

        Retrieves a list of business object definition description suggestion keys for all suggestions registered for a specific business object definition. The result list is sorted by userId in ascending order.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_definition_description_suggestion_get_business_object_definition_description_suggestions_with_http_info(namespace, business_object_definition_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str namespace: the namespace (required)
        :param str business_object_definition_name: the business object definition name (required)
        :return: BusinessObjectDefinitionDescriptionSuggestionKeys
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['namespace', 'business_object_definition_name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method business_object_definition_description_suggestion_get_business_object_definition_description_suggestions" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'namespace' is set
        if ('namespace' not in local_var_params or
                local_var_params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `business_object_definition_description_suggestion_get_business_object_definition_description_suggestions`")  # noqa: E501
        # verify the required parameter 'business_object_definition_name' is set
        if ('business_object_definition_name' not in local_var_params or
                local_var_params['business_object_definition_name'] is None):
            raise ValueError("Missing the required parameter `business_object_definition_name` when calling `business_object_definition_description_suggestion_get_business_object_definition_description_suggestions`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'namespace' in local_var_params:
            path_params['namespace'] = local_var_params['namespace']  # noqa: E501
        if 'business_object_definition_name' in local_var_params:
            path_params['businessObjectDefinitionName'] = local_var_params['business_object_definition_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/businessObjectDefinitionDescriptionSuggestions/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BusinessObjectDefinitionDescriptionSuggestionKeys',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def business_object_definition_description_suggestion_search_business_object_definition_description_suggestions(self, business_object_definition_description_suggestion_search_request, **kwargs):  # noqa: E501
        """searchBusinessObjectDefinitionDescriptionSuggestions  # noqa: E501

        Retrieve a list of business object definition description suggestions meeting the search criteria filters and fields request.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_definition_description_suggestion_search_business_object_definition_description_suggestions(business_object_definition_description_suggestion_search_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param BusinessObjectDefinitionDescriptionSuggestionSearchRequest business_object_definition_description_suggestion_search_request: the search criteria needed to find a list of business object definition description suggestions (required)
        :param str fields: the field options for the business object definition description suggestions search response. The valid field options are: status, descriptionSuggestion, createdByUserId, createdOn
        :return: BusinessObjectDefinitionDescriptionSuggestionSearchResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.business_object_definition_description_suggestion_search_business_object_definition_description_suggestions_with_http_info(business_object_definition_description_suggestion_search_request, **kwargs)  # noqa: E501
        else:
            (data) = self.business_object_definition_description_suggestion_search_business_object_definition_description_suggestions_with_http_info(business_object_definition_description_suggestion_search_request, **kwargs)  # noqa: E501
            return data

    def business_object_definition_description_suggestion_search_business_object_definition_description_suggestions_with_http_info(self, business_object_definition_description_suggestion_search_request, **kwargs):  # noqa: E501
        """searchBusinessObjectDefinitionDescriptionSuggestions  # noqa: E501

        Retrieve a list of business object definition description suggestions meeting the search criteria filters and fields request.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_definition_description_suggestion_search_business_object_definition_description_suggestions_with_http_info(business_object_definition_description_suggestion_search_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param BusinessObjectDefinitionDescriptionSuggestionSearchRequest business_object_definition_description_suggestion_search_request: the search criteria needed to find a list of business object definition description suggestions (required)
        :param str fields: the field options for the business object definition description suggestions search response. The valid field options are: status, descriptionSuggestion, createdByUserId, createdOn
        :return: BusinessObjectDefinitionDescriptionSuggestionSearchResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['business_object_definition_description_suggestion_search_request', 'fields']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method business_object_definition_description_suggestion_search_business_object_definition_description_suggestions" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'business_object_definition_description_suggestion_search_request' is set
        if ('business_object_definition_description_suggestion_search_request' not in local_var_params or
                local_var_params['business_object_definition_description_suggestion_search_request'] is None):
            raise ValueError("Missing the required parameter `business_object_definition_description_suggestion_search_request` when calling `business_object_definition_description_suggestion_search_business_object_definition_description_suggestions`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'fields' in local_var_params:
            query_params.append(('fields', local_var_params['fields']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'business_object_definition_description_suggestion_search_request' in local_var_params:
            body_params = local_var_params['business_object_definition_description_suggestion_search_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/businessObjectDefinitionDescriptionSuggestions/search', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BusinessObjectDefinitionDescriptionSuggestionSearchResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def business_object_definition_description_suggestion_update_business_object_definition_description_suggestion(self, namespace, business_object_definition_name, user_id, business_object_definition_description_suggestion_update_request, **kwargs):  # noqa: E501
        """updateBusinessObjectDefinitionDescriptionSuggestion  # noqa: E501

        Updates an existing business object definition description suggestion by key.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_definition_description_suggestion_update_business_object_definition_description_suggestion(namespace, business_object_definition_name, user_id, business_object_definition_description_suggestion_update_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str namespace: the namespace (required)
        :param str business_object_definition_name: the business object definition name (required)
        :param str user_id: the user id (required)
        :param BusinessObjectDefinitionDescriptionSuggestionUpdateRequest business_object_definition_description_suggestion_update_request: the information needed to update the business object definition description suggestion (required)
        :return: BusinessObjectDefinitionDescriptionSuggestion
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.business_object_definition_description_suggestion_update_business_object_definition_description_suggestion_with_http_info(namespace, business_object_definition_name, user_id, business_object_definition_description_suggestion_update_request, **kwargs)  # noqa: E501
        else:
            (data) = self.business_object_definition_description_suggestion_update_business_object_definition_description_suggestion_with_http_info(namespace, business_object_definition_name, user_id, business_object_definition_description_suggestion_update_request, **kwargs)  # noqa: E501
            return data

    def business_object_definition_description_suggestion_update_business_object_definition_description_suggestion_with_http_info(self, namespace, business_object_definition_name, user_id, business_object_definition_description_suggestion_update_request, **kwargs):  # noqa: E501
        """updateBusinessObjectDefinitionDescriptionSuggestion  # noqa: E501

        Updates an existing business object definition description suggestion by key.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.business_object_definition_description_suggestion_update_business_object_definition_description_suggestion_with_http_info(namespace, business_object_definition_name, user_id, business_object_definition_description_suggestion_update_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str namespace: the namespace (required)
        :param str business_object_definition_name: the business object definition name (required)
        :param str user_id: the user id (required)
        :param BusinessObjectDefinitionDescriptionSuggestionUpdateRequest business_object_definition_description_suggestion_update_request: the information needed to update the business object definition description suggestion (required)
        :return: BusinessObjectDefinitionDescriptionSuggestion
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['namespace', 'business_object_definition_name', 'user_id', 'business_object_definition_description_suggestion_update_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method business_object_definition_description_suggestion_update_business_object_definition_description_suggestion" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'namespace' is set
        if ('namespace' not in local_var_params or
                local_var_params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `business_object_definition_description_suggestion_update_business_object_definition_description_suggestion`")  # noqa: E501
        # verify the required parameter 'business_object_definition_name' is set
        if ('business_object_definition_name' not in local_var_params or
                local_var_params['business_object_definition_name'] is None):
            raise ValueError("Missing the required parameter `business_object_definition_name` when calling `business_object_definition_description_suggestion_update_business_object_definition_description_suggestion`")  # noqa: E501
        # verify the required parameter 'user_id' is set
        if ('user_id' not in local_var_params or
                local_var_params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `business_object_definition_description_suggestion_update_business_object_definition_description_suggestion`")  # noqa: E501
        # verify the required parameter 'business_object_definition_description_suggestion_update_request' is set
        if ('business_object_definition_description_suggestion_update_request' not in local_var_params or
                local_var_params['business_object_definition_description_suggestion_update_request'] is None):
            raise ValueError("Missing the required parameter `business_object_definition_description_suggestion_update_request` when calling `business_object_definition_description_suggestion_update_business_object_definition_description_suggestion`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'namespace' in local_var_params:
            path_params['namespace'] = local_var_params['namespace']  # noqa: E501
        if 'business_object_definition_name' in local_var_params:
            path_params['businessObjectDefinitionName'] = local_var_params['business_object_definition_name']  # noqa: E501
        if 'user_id' in local_var_params:
            path_params['userId'] = local_var_params['user_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'business_object_definition_description_suggestion_update_request' in local_var_params:
            body_params = local_var_params['business_object_definition_description_suggestion_update_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/businessObjectDefinitionDescriptionSuggestions/namespaces/{namespace}/businessObjectDefinitionNames/{businessObjectDefinitionName}/userIds/{userId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BusinessObjectDefinitionDescriptionSuggestion',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import herdsdk
from herdsdk.api.business_object_definition_description_suggestion_api import BusinessObjectDefinitionDescriptionSuggestionApi  # noqa: E501
from herdsdk.rest import ApiException


class TestBusinessObjectDefinitionDescriptionSuggestionApi(unittest.TestCase):
    """BusinessObjectDefinitionDescriptionSuggestionApi unit test stubs"""

    def setUp(self):
        self.api = herdsdk.api.business_object_definition_description_suggestion_api.BusinessObjectDefinitionDescriptionSuggestionApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_business_object_definition_description_suggestion_accept_business_object_definition_description_suggestion(self):
        """Test case for business_object_definition_description_suggestion_accept_business_object_definition_description_suggestion

        acceptBusinessObjectDefinitionDescriptionSuggestion  # noqa: E501
        """
        pass

    def test_business_object_definition_description_suggestion_create_business_object_definition_description_suggestion(self):
        """Test case for business_object_definition_description_suggestion_create_business_object_definition_description_suggestion

        createBusinessObjectDefinitionDescriptionSuggestion  # noqa: E501
        """
        pass

    def test_business_object_definition_description_suggestion_delete_business_object_definition_description_suggestion(self):
        """Test case for business_object_definition_description_suggestion_delete_business_object_definition_description_suggestion

        deleteBusinessObjectDefinitionDescriptionSuggestion  # noqa: E501
        """
        pass

    def test_business_object_definition_description_suggestion_get_business_object_definition_description_suggestion_by_key(self):
        """Test case for business_object_definition_description_suggestion_get_business_object_definition_description_suggestion_by_key

        getBusinessObjectDefinitionDescriptionSuggestionByKey  # noqa: E501
        """
        pass

    def test_business_object_definition_description_suggestion_get_business_object_definition_description_suggestions(self):
        """Test case for business_object_definition_description_suggestion_get_business_object_definition_description_suggestions

        getBusinessObjectDefinitionDescriptionSuggestions  # noqa: E501
        """
        pass

    def test_business_object_definition_description_suggestion_search_business_object_definition_description_suggestions(self):
        """Test case for business_object_definition_description_suggestion_search_business_object_definition_description_suggestions

        searchBusinessObjectDefinitionDescriptionSuggestions  # noqa: E501
        """
        pass

    def test_business_object_definition_description_suggestion_update_business_object_definition_description_suggestion(self):
        """Test case for business_object_definition_description_suggestion_update_business_object_definition_description_suggestion

        updateBusinessObjectDefinitionDescriptionSuggestion  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class Namespace(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'namespace_code': 'str',
        'charge_code': 'str',
        's3_key_prefix': 'str'
    }

    attribute_map = {
        'namespace_code': 'namespaceCode',
        'charge_code': 'chargeCode',
        's3_key_prefix': 's3KeyPrefix'
    }

    def __init__(self, namespace_code=None, charge_code=None, s3_key_prefix=None):  # noqa: E501
        """Namespace - a model defined in OpenAPI"""  # noqa: E501

        self._namespace_code = None
        self._charge_code = None
        self._s3_key_prefix = None
        self.discriminator = None

        self.namespace_code = namespace_code
        if charge_code is not None:
            self.charge_code = charge_code
        if s3_key_prefix is not None:
            self.s3_key_prefix = s3_key_prefix

    @property
    def namespace_code(self):
        """Gets the namespace_code of this Namespace.  # noqa: E501

        The Namespace code  # noqa: E501

        :return: The namespace_code of this Namespace.  # noqa: E501
        :rtype: str
        """
        return self._namespace_code

    @namespace_code.setter
    def namespace_code(self, namespace_code):
        """Sets the namespace_code of this Namespace.

        The Namespace code  # noqa: E501

        :param namespace_code: The namespace_code of this Namespace.  # noqa: E501
        :type: str
        """
        if namespace_code is None:
            raise ValueError("Invalid value for `namespace_code`, must not be `None`")  # noqa: E501

        self._namespace_code = namespace_code

    @property
    def charge_code(self):
        """Gets the charge_code of this Namespace.  # noqa: E501

        An optional charge code that is associated with the Namespace  # noqa: E501

        :return: The charge_code of this Namespace.  # noqa: E501
        :rtype: str
        """
        return self._charge_code

    @charge_code.setter
    def charge_code(self, charge_code):
        """Sets the charge_code of this Namespace.

        An optional charge code that is associated with the Namespace  # noqa: E501

        :param charge_code: The charge_code of this Namespace.  # noqa: E501
        :type: str
        """

        self._charge_code = charge_code

    @property
    def s3_key_prefix(self):
        """Gets the s3_key_prefix of this Namespace.  # noqa: E501

        The S3 key prefix for the Namespace. This value is automatically generated by the system from the Namespace code. Note that the                   S3 key prefix will not contain a trailing \"directory\" separator and it will be up to the caller to append one as needed                  # noqa: E501

        :return: The s3_key_prefix of this Namespace.  # noqa: E501
        :rtype: str
        """
        return self._s3_key_prefix

    @s3_key_prefix.setter
    def s3_key_prefix(self, s3_key_prefix):
        """Sets the s3_key_prefix of this Namespace.

        The S3 key prefix for the Namespace. This value is automatically generated by the system from the Namespace code. Note that the                   S3 key prefix will not contain a trailing \"directory\" separator and it will be up to the caller to append one as needed                  # noqa: E501

        :param s3_key_prefix: The s3_key_prefix of this Namespace.  # noqa: E501
        :type: str
        """

        self._s3_key_prefix = s3_key_prefix

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Namespace):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BusinessObjectDataPartitionsRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'namespace': 'str',
        'business_object_definition_name': 'str',
        'business_object_format_usage': 'str',
        'business_object_format_file_type': 'str',
        'business_object_format_version': 'int',
        'partition_value_filters': 'list[PartitionValueFilter]',
        'business_object_data_version': 'int',
        'business_object_data_status': 'str',
        'storage_names': 'list[str]',
        'allow_missing_data': 'bool',
        'include_all_registered_sub_partitions': 'bool',
        'suppress_scan_for_unregistered_sub_partitions': 'bool'
    }

    attribute_map = {
        'namespace': 'namespace',
        'business_object_definition_name': 'businessObjectDefinitionName',
        'business_object_format_usage': 'businessObjectFormatUsage',
        'business_object_format_file_type': 'businessObjectFormatFileType',
        'business_object_format_version': 'businessObjectFormatVersion',
        'partition_value_filters': 'partitionValueFilters',
        'business_object_data_version': 'businessObjectDataVersion',
        'business_object_data_status': 'businessObjectDataStatus',
        'storage_names': 'storageNames',
        'allow_missing_data': 'allowMissingData',
        'include_all_registered_sub_partitions': 'includeAllRegisteredSubPartitions',
        'suppress_scan_for_unregistered_sub_partitions': 'suppressScanForUnregisteredSubPartitions'
    }

    def __init__(self, namespace=None, business_object_definition_name=None, business_object_format_usage=None, business_object_format_file_type=None, business_object_format_version=None, partition_value_filters=None, business_object_data_version=None, business_object_data_status=None, storage_names=None, allow_missing_data=None, include_all_registered_sub_partitions=None, suppress_scan_for_unregistered_sub_partitions=None):  # noqa: E501
        """BusinessObjectDataPartitionsRequest - a model defined in OpenAPI"""  # noqa: E501

        self._namespace = None
        self._business_object_definition_name = None
        self._business_object_format_usage = None
        self._business_object_format_file_type = None
        self._business_object_format_version = None
        self._partition_value_filters = None
        self._business_object_data_version = None
        self._business_object_data_status = None
        self._storage_names = None
        self._allow_missing_data = None
        self._include_all_registered_sub_partitions = None
        self._suppress_scan_for_unregistered_sub_partitions = None
        self.discriminator = None

        self.namespace = namespace
        self.business_object_definition_name = business_object_definition_name
        self.business_object_format_usage = business_object_format_usage
        self.business_object_format_file_type = business_object_format_file_type
        if business_object_format_version is not None:
            self.business_object_format_version = business_object_format_version
        if partition_value_filters is not None:
            self.partition_value_filters = partition_value_filters
        if business_object_data_version is not None:
            self.business_object_data_version = business_object_data_version
        if business_object_data_status is not None:
            self.business_object_data_status = business_object_data_status
        if storage_names is not None:
            self.storage_names = storage_names
        if allow_missing_data is not None:
            self.allow_missing_data = allow_missing_data
        if include_all_registered_sub_partitions is not None:
            self.include_all_registered_sub_partitions = include_all_registered_sub_partitions
        if suppress_scan_for_unregistered_sub_partitions is not None:
            self.suppress_scan_for_unregistered_sub_partitions = suppress_scan_for_unregistered_sub_partitions

    @property
    def namespace(self):
        """Gets the namespace of this BusinessObjectDataPartitionsRequest.  # noqa: E501


        :return: The namespace of this BusinessObjectDataPartitionsRequest.  # noqa: E501
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """Sets the namespace of this BusinessObjectDataPartitionsRequest.


        :param namespace: The namespace of this BusinessObjectDataPartitionsRequest.  # noqa: E501
        :type: str
        """
        if namespace is None:
            raise ValueError("Invalid value for `namespace`, must not be `None`")  # noqa: E501

        self._namespace = namespace

    @property
    def business_object_definition_name(self):
        """Gets the business_object_definition_name of this BusinessObjectDataPartitionsRequest.  # noqa: E501


        :return: The business_object_definition_name of this BusinessObjectDataPartitionsRequest.  # noqa: E501
        :rtype: str
        """
        return self._business_object_definition_name

    @business_object_definition_name.setter
    def business_object_definition_name(self, business_object_definition_name):
        """Sets the business_object_definition_name of this BusinessObjectDataPartitionsRequest.


        :param business_object_definition_name: The business_object_definition_name of this BusinessObjectDataPartitionsRequest.  # noqa: E501
        :type: str
        """
        if business_object_definition_name is None:
            raise ValueError("Invalid value for `business_object_definition_name`, must not be `None`")  # noqa: E501

        self._business_object_definition_name = business_object_definition_name

    @property
    def business_object_format_usage(self):
        """Gets the business_object_format_usage of this BusinessObjectDataPartitionsRequest.  # noqa: E501


        :return: The business_object_format_usage of this BusinessObjectDataPartitionsRequest.  # noqa: E501
        :rtype: str
        """
        return self._business_object_format_usage

    @business_object_format_usage.setter
    def business_object_format_usage(self, business_object_format_usage):
        """Sets the business_object_format_usage of this BusinessObjectDataPartitionsRequest.


        :param business_object_format_usage: The business_object_format_usage of this BusinessObjectDataPartitionsRequest.  # noqa: E501
        :type: str
        """
        if business_object_format_usage is None:
            raise ValueError("Invalid value for `business_object_format_usage`, must not be `None`")  # noqa: E501

        self._business_object_format_usage = business_object_format_usage

    @property
    def business_object_format_file_type(self):
        """Gets the business_object_format_file_type of this BusinessObjectDataPartitionsRequest.  # noqa: E501


        :return: The business_object_format_file_type of this BusinessObjectDataPartitionsRequest.  # noqa: E501
        :rtype: str
        """
        return self._business_object_format_file_type

    @business_object_format_file_type.setter
    def business_object_format_file_type(self, business_object_format_file_type):
        """Sets the business_object_format_file_type of this BusinessObjectDataPartitionsRequest.


        :param business_object_format_file_type: The business_object_format_file_type of this BusinessObjectDataPartitionsRequest.  # noqa: E501
        :type: str
        """
        if business_object_format_file_type is None:
            raise ValueError("Invalid value for `business_object_format_file_type`, must not be `None`")  # noqa: E501

        self._business_object_format_file_type = business_object_format_file_type

    @property
    def business_object_format_version(self):
        """Gets the business_object_format_version of this BusinessObjectDataPartitionsRequest.  # noqa: E501


        :return: The business_object_format_version of this BusinessObjectDataPartitionsRequest.  # noqa: E501
        :rtype: int
        """
        return self._business_object_format_version

    @business_object_format_version.setter
    def business_object_format_version(self, business_object_format_version):
        """Sets the business_object_format_version of this BusinessObjectDataPartitionsRequest.


        :param business_object_format_version: The business_object_format_version of this BusinessObjectDataPartitionsRequest.  # noqa: E501
        :type: int
        """

        self._business_object_format_version = business_object_format_version

    @property
    def partition_value_filters(self):
        """Gets the partition_value_filters of this BusinessObjectDataPartitionsRequest.  # noqa: E501


        :return: The partition_value_filters of this BusinessObjectDataPartitionsRequest.  # noqa: E501
        :rtype: list[PartitionValueFilter]
        """
        return self._partition_value_filters

    @partition_value_filters.setter
    def partition_value_filters(self, partition_value_filters):
        """Sets the partition_value_filters of this BusinessObjectDataPartitionsRequest.


        :param partition_value_filters: The partition_value_filters of this BusinessObjectDataPartitionsRequest.  # noqa: E501
        :type: list[PartitionValueFilter]
        """

        self._partition_value_filters = partition_value_filters

    @property
    def business_object_data_version(self):
        """Gets the business_object_data_version of this BusinessObjectDataPartitionsRequest.  # noqa: E501


        :return: The business_object_data_version of this BusinessObjectDataPartitionsRequest.  # noqa: E501
        :rtype: int
        """
        return self._business_object_data_version

    @business_object_data_version.setter
    def business_object_data_version(self, business_object_data_version):
        """Sets the business_object_data_version of this BusinessObjectDataPartitionsRequest.


        :param business_object_data_version: The business_object_data_version of this BusinessObjectDataPartitionsRequest.  # noqa: E501
        :type: int
        """

        self._business_object_data_version = business_object_data_version

    @property
    def business_object_data_status(self):
        """Gets the business_object_data_status of this BusinessObjectDataPartitionsRequest.  # noqa: E501

        An optional Business Object Data Status value for available Business Object Data. Accepted values are VALID and all                   pre-registration status values, such as PROCESSING, UPLOADING, and PENDING_VALID. Default value is VALID. The request cannot                   contain both businessObjectDataVersion and businessObjectDataStatus values                  # noqa: E501

        :return: The business_object_data_status of this BusinessObjectDataPartitionsRequest.  # noqa: E501
        :rtype: str
        """
        return self._business_object_data_status

    @business_object_data_status.setter
    def business_object_data_status(self, business_object_data_status):
        """Sets the business_object_data_status of this BusinessObjectDataPartitionsRequest.

        An optional Business Object Data Status value for available Business Object Data. Accepted values are VALID and all                   pre-registration status values, such as PROCESSING, UPLOADING, and PENDING_VALID. Default value is VALID. The request cannot                   contain both businessObjectDataVersion and businessObjectDataStatus values                  # noqa: E501

        :param business_object_data_status: The business_object_data_status of this BusinessObjectDataPartitionsRequest.  # noqa: E501
        :type: str
        """

        self._business_object_data_status = business_object_data_status

    @property
    def storage_names(self):
        """Gets the storage_names of this BusinessObjectDataPartitionsRequest.  # noqa: E501


        :return: The storage_names of this BusinessObjectDataPartitionsRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._storage_names

    @storage_names.setter
    def storage_names(self, storage_names):
        """Sets the storage_names of this BusinessObjectDataPartitionsRequest.


        :param storage_names: The storage_names of this BusinessObjectDataPartitionsRequest.  # noqa: E501
        :type: list[str]
        """

        self._storage_names = storage_names

    @property
    def allow_missing_data(self):
        """Gets the allow_missing_data of this BusinessObjectDataPartitionsRequest.  # noqa: E501


        :return: The allow_missing_data of this BusinessObjectDataPartitionsRequest.  # noqa: E501
        :rtype: bool
        """
        return self._allow_missing_data

    @allow_missing_data.setter
    def allow_missing_data(self, allow_missing_data):
        """Sets the allow_missing_data of this BusinessObjectDataPartitionsRequest.


        :param allow_missing_data: The allow_missing_data of this BusinessObjectDataPartitionsRequest.  # noqa: E501
        :type: bool
        """

        self._allow_missing_data = allow_missing_data

    @property
    def include_all_registered_sub_partitions(self):
        """Gets the include_all_registered_sub_partitions of this BusinessObjectDataPartitionsRequest.  # noqa: E501

        Specifies to perform an exhaustive search to return availability for ALL registered sub-partitions (registered as individual                   business object data instances) except for the ones with \"DELETED\" status. This parameter has no impact when business object data version is                   specified. Default value is false, which means that this endpoint ignores any \"not available\" registered sub-partitions when it finds at least                   one \"VALID\" registered sub-partition for a requested business object data partition value.                   If true, the call would fail with a \"Not Found\" (status code 404) error when it finds at least one \"not available\" (except for \"DELETED\")                   registered sub-partition for a requested business object data partition value                  # noqa: E501

        :return: The include_all_registered_sub_partitions of this BusinessObjectDataPartitionsRequest.  # noqa: E501
        :rtype: bool
        """
        return self._include_all_registered_sub_partitions

    @include_all_registered_sub_partitions.setter
    def include_all_registered_sub_partitions(self, include_all_registered_sub_partitions):
        """Sets the include_all_registered_sub_partitions of this BusinessObjectDataPartitionsRequest.

        Specifies to perform an exhaustive search to return availability for ALL registered sub-partitions (registered as individual                   business object data instances) except for the ones with \"DELETED\" status. This parameter has no impact when business object data version is                   specified. Default value is false, which means that this endpoint ignores any \"not available\" registered sub-partitions when it finds at least                   one \"VALID\" registered sub-partition for a requested business object data partition value.                   If true, the call would fail with a \"Not Found\" (status code 404) error when it finds at least one \"not available\" (except for \"DELETED\")                   registered sub-partition for a requested business object data partition value                  # noqa: E501

        :param include_all_registered_sub_partitions: The include_all_registered_sub_partitions of this BusinessObjectDataPartitionsRequest.  # noqa: E501
        :type: bool
        """

        self._include_all_registered_sub_partitions = include_all_registered_sub_partitions

    @property
    def suppress_scan_for_unregistered_sub_partitions(self):
        """Gets the suppress_scan_for_unregistered_sub_partitions of this BusinessObjectDataPartitionsRequest.  # noqa: E501

        Specifies to suppress scanning of registered storage files to discover sub-partitions and instead of that relies on business                   object data registration information to extract primary and sub-partition (if any) values required to identify Hive table partitions. Default                   value is false. If true, the call would fail with a \"Bad Request\" (status code 400) error when number of partitions in any of the discovered                   business object data instances does not match to the number of partition columns in the business object format being used to generate the DDL                  # noqa: E501

        :return: The suppress_scan_for_unregistered_sub_partitions of this BusinessObjectDataPartitionsRequest.  # noqa: E501
        :rtype: bool
        """
        return self._suppress_scan_for_unregistered_sub_partitions

    @suppress_scan_for_unregistered_sub_partitions.setter
    def suppress_scan_for_unregistered_sub_partitions(self, suppress_scan_for_unregistered_sub_partitions):
        """Sets the suppress_scan_for_unregistered_sub_partitions of this BusinessObjectDataPartitionsRequest.

        Specifies to suppress scanning of registered storage files to discover sub-partitions and instead of that relies on business                   object data registration information to extract primary and sub-partition (if any) values required to identify Hive table partitions. Default                   value is false. If true, the call would fail with a \"Bad Request\" (status code 400) error when number of partitions in any of the discovered                   business object data instances does not match to the number of partition columns in the business object format being used to generate the DDL                  # noqa: E501

        :param suppress_scan_for_unregistered_sub_partitions: The suppress_scan_for_unregistered_sub_partitions of this BusinessObjectDataPartitionsRequest.  # noqa: E501
        :type: bool
        """

        self._suppress_scan_for_unregistered_sub_partitions = suppress_scan_for_unregistered_sub_partitions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BusinessObjectDataPartitionsRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import herdsdk
from herdsdk.api.business_object_format_to_external_interface_mapping_api import BusinessObjectFormatToExternalInterfaceMappingApi  # noqa: E501
from herdsdk.rest import ApiException


class TestBusinessObjectFormatToExternalInterfaceMappingApi(unittest.TestCase):
    """BusinessObjectFormatToExternalInterfaceMappingApi unit test stubs"""

    def setUp(self):
        self.api = herdsdk.api.business_object_format_to_external_interface_mapping_api.BusinessObjectFormatToExternalInterfaceMappingApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_business_object_formatto_external_interface_mapping_create_business_object_format_external_interface(self):
        """Test case for business_object_formatto_external_interface_mapping_create_business_object_format_external_interface

        createBusinessObjectFormatExternalInterface  # noqa: E501
        """
        pass

    def test_business_object_formatto_external_interface_mapping_delete_business_object_format_external_interface(self):
        """Test case for business_object_formatto_external_interface_mapping_delete_business_object_format_external_interface

        deleteBusinessObjectFormatExternalInterface  # noqa: E501
        """
        pass

    def test_business_object_formatto_external_interface_mapping_get_business_object_format_external_interface(self):
        """Test case for business_object_formatto_external_interface_mapping_get_business_object_format_external_interface

        getBusinessObjectFormatExternalInterface  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
